# aiomothr

[![pipeline status](http://gitlab.rs21.io/mothr/client-libraries/aiomothr/badges/master/pipeline.svg)](http://gitlab.rs21.io/mothr/client-libraries/aiomothr/commits/master)
[![coverage report](http://gitlab.rs21.io/mothr/client-libraries/aiomothr/badges/master/coverage.svg)](http://gitlab.rs21.io/mothr/client-libraries/aiomothr/commits/master)
